@@ -24,14 +24,16 @@ from .version import __version__
 from pathlib import Path
 from .dict_utils import *
 
-###--------------------------------------------------------------------------------------------
+DEFAULT_CLICK_CONTEXT = dict(help_option_names=['-h', '--help'])
+
+
 
 @click.group(context_settings=DEFAULT_CLICK_CONTEXT)
 def cli():
     """DSO CLI"""
     pass
 
-###--------------------------------------------------------------------------------------------
+
 
 @cli.group(context_settings=DEFAULT_CLICK_CONTEXT)
 def config():
@@ -40,7 +42,7 @@ def config():
     """
     pass
 
-###--------------------------------------------------------------------------------------------
+
 
 @cli.group(context_settings=DEFAULT_CLICK_CONTEXT)
 def parameter():
@@ -49,7 +51,7 @@ def parameter():
     """
     pass
 
-###--------------------------------------------------------------------------------------------
+
 
 @cli.group(context_settings=DEFAULT_CLICK_CONTEXT)
 def secret():
@@ -58,7 +60,7 @@ def secret():
     """
     pass
 
-###--------------------------------------------------------------------------------------------
+
 
 @cli.group(context_settings=DEFAULT_CLICK_CONTEXT)
 def template():
@@ -67,7 +69,7 @@ def template():
     """
     pass
 
-###--------------------------------------------------------------------------------------------
+
 
 @cli.group(context_settings=DEFAULT_CLICK_CONTEXT)
 def package():
@@ -76,7 +78,7 @@ def package():
     """
     pass
 
-###--------------------------------------------------------------------------------------------
+
 
 @cli.group(context_settings=DEFAULT_CLICK_CONTEXT)
 def release():
@@ -85,7 +87,7 @@ def release():
     """
     pass
 
-###--------------------------------------------------------------------------------------------
+
 
 # @cli.group(context_settings=DEFAULT_CLICK_CONTEXT)
 # def provision():
@@ -94,7 +96,7 @@ def release():
 #     """
 #     pass
 
-# ###--------------------------------------------------------------------------------------------
+# 
 
 # @cli.group(context_settings=DEFAULT_CLICK_CONTEXT)
 # def deploy():
@@ -103,9 +105,9 @@ def release():
 #     """
 #     pass
 
-###--------------------------------------------------------------------------------------------
-###--------------------------------------------------------------------------------------------
-###--------------------------------------------------------------------------------------------
+
+
+
 
 @cli.command('version', context_settings=DEFAULT_CLICK_CONTEXT, short_help=f"{CLI_COMMANDS_SHORT_HELP['version']}")
 def version():
@@ -115,9 +117,9 @@ def version():
     click.echo(f"DSO CLI: {__version__}\nPython: {platform.sys.version}")
 
 
-###--------------------------------------------------------------------------------------------
-###--------------------------------------------------------------------------------------------
-###--------------------------------------------------------------------------------------------
+
+
+
 
 @parameter.command('add', context_settings=DEFAULT_CLICK_CONTEXT, short_help=f"{CLI_COMMANDS_SHORT_HELP['parameter']['add']}")
 @command_doc(CLI_COMMANDS_HELP['parameter']['add'])
@@ -195,7 +197,7 @@ def add_parameter(key, key_option, value, value_option, stage, input, format, ve
             output = format_data(result, '', 'json') ### FIXME: use a global output format setting
             if output: Pager.page(output)
 
-###--------------------------------------------------------------------------------------------
+
 
 @parameter.command('list', context_settings=DEFAULT_CLICK_CONTEXT, short_help=f"{CLI_COMMANDS_SHORT_HELP['parameter']['list']}")
 @command_doc(CLI_COMMANDS_HELP['parameter']['list'])
@@ -241,7 +243,7 @@ def list_parameter(stage, uninherited, filter, query_all, query, format, verbosi
         if verbosity >= log_levels['full']:
             raise
 
-###--------------------------------------------------------------------------------------------
+
 
 @parameter.command('get', context_settings=DEFAULT_CLICK_CONTEXT, short_help=f"{CLI_COMMANDS_SHORT_HELP['parameter']['get']}")
 @command_doc(CLI_COMMANDS_HELP['parameter']['get'])
@@ -284,7 +286,7 @@ def get_parameter(key, key_option, stage, revision, query_all, query, format, ve
         if verbosity >= log_levels['full']:
             raise
 
-###--------------------------------------------------------------------------------------------
+
 
 @parameter.command('history', context_settings=DEFAULT_CLICK_CONTEXT, short_help=f"{CLI_COMMANDS_SHORT_HELP['parameter']['history']}")
 @command_doc(CLI_COMMANDS_HELP['parameter']['history'])
@@ -326,7 +328,7 @@ def history_parameter(key, key_option, stage, query_all, query, format, verbosit
         if verbosity >= log_levels['full']:
             raise
 
-###--------------------------------------------------------------------------------------------
+
 
 @parameter.command('delete', context_settings=DEFAULT_CLICK_CONTEXT, short_help=f"{CLI_COMMANDS_SHORT_HELP['parameter']['delete']}")
 @command_doc(CLI_COMMANDS_HELP['parameter']['delete'])
@@ -389,9 +391,9 @@ def delete_parameter(key, key_option, input, format, stage, verbosity, global_sc
             output = format_data(result, '', 'json') ### FIXME: use a global output format setting
             if output: Pager.page(output)
 
-###--------------------------------------------------------------------------------------------
-###--------------------------------------------------------------------------------------------
-###--------------------------------------------------------------------------------------------
+
+
+
 
 @secret.command('add', context_settings=DEFAULT_CLICK_CONTEXT, short_help=f"{CLI_COMMANDS_SHORT_HELP['secret']['add']}")
 @command_doc(CLI_COMMANDS_HELP['secret']['add'])
@@ -467,7 +469,7 @@ def add_secret(key, key_option, stage, input, format, verbosity, global_scope, p
             output = format_data(result, '', 'json') ### FIXME: use a global output format setting
             if output: Pager.page(output)
 
-###--------------------------------------------------------------------------------------------
+
 
 @secret.command('list', context_settings=DEFAULT_CLICK_CONTEXT, short_help=f"{CLI_COMMANDS_SHORT_HELP['secret']['list']}")
 @command_doc(CLI_COMMANDS_HELP['secret']['list'])
@@ -514,7 +516,7 @@ def list_secret(stage, uninherited, decrypt, filter, query_all, query, format, v
         if verbosity >= log_levels['full']:
             raise
 
-###--------------------------------------------------------------------------------------------
+
 
 @secret.command('get', context_settings=DEFAULT_CLICK_CONTEXT, short_help=f"{CLI_COMMANDS_SHORT_HELP['secret']['get']}")
 @command_doc(CLI_COMMANDS_HELP['secret']['get'])
@@ -561,7 +563,7 @@ def get_secret(key, key_option, stage, revision, decrypt, query_all, query, form
         if verbosity >= log_levels['full']:
             raise
 
-###--------------------------------------------------------------------------------------------
+
 
 @secret.command('history', context_settings=DEFAULT_CLICK_CONTEXT, short_help=f"{CLI_COMMANDS_SHORT_HELP['secret']['history']}")
 @command_doc(CLI_COMMANDS_HELP['secret']['history'])
@@ -607,7 +609,7 @@ def history_secret(key, key_option, stage, decrypt, query_all, query, format, ve
         if verbosity >= log_levels['full']:
             raise
 
-###--------------------------------------------------------------------------------------------
+
 
 @secret.command('delete', context_settings=DEFAULT_CLICK_CONTEXT, short_help=f"{CLI_COMMANDS_SHORT_HELP['secret']['delete']}")
 @command_doc(CLI_COMMANDS_HELP['secret']['delete'])
@@ -670,9 +672,9 @@ def delete_secret(key, key_option, input, format, stage, verbosity, global_scope
             output = format_data(result, '', 'json') ### FIXME: use a global output format setting
             if output: Pager.page(output)
 
-###--------------------------------------------------------------------------------------------
-###--------------------------------------------------------------------------------------------
-###--------------------------------------------------------------------------------------------
+
+
+
 
 @template.command('list', context_settings=DEFAULT_CLICK_CONTEXT, short_help=f"{CLI_COMMANDS_SHORT_HELP['template']['list']}")
 @command_doc(CLI_COMMANDS_HELP['template']['list'])
@@ -721,7 +723,7 @@ def list_template(uninherited, stage, include_contents, filter, query_all, query
         if verbosity >= log_levels['full']:
             raise
 
-###--------------------------------------------------------------------------------------------
+
 
 @template.command('add', context_settings=DEFAULT_CLICK_CONTEXT, short_help=f"{CLI_COMMANDS_SHORT_HELP['template']['add']}")
 @command_doc(CLI_COMMANDS_HELP['template']['add'])
@@ -853,7 +855,7 @@ def add_template(key, key_option, render_path, input, recursive, stage, verbosit
             output = format_data(result, '', 'json') ### FIXME: use a global output format setting
             if output: Pager.page(output)
 
-###--------------------------------------------------------------------------------------------
+
 
 @template.command('get', context_settings=DEFAULT_CLICK_CONTEXT, short_help=f"{CLI_COMMANDS_SHORT_HELP['template']['get']}")
 @command_doc(CLI_COMMANDS_HELP['template']['get'])
@@ -898,7 +900,7 @@ def get_template(key, key_option, stage, revision, include_contents, query_all,
         if verbosity >= log_levels['full']:
             raise
 
-###--------------------------------------------------------------------------------------------
+
 
 @template.command('history', context_settings=DEFAULT_CLICK_CONTEXT, short_help=f"{CLI_COMMANDS_SHORT_HELP['template']['history']}")
 @command_doc(CLI_COMMANDS_HELP['template']['history'])
@@ -945,7 +947,7 @@ def history_template(key, key_option, stage, include_contents, query_all, query,
         if verbosity >= log_levels['full']:
             raise
 
-###--------------------------------------------------------------------------------------------
+
 
 @template.command('delete', context_settings=DEFAULT_CLICK_CONTEXT, short_help=f"{CLI_COMMANDS_SHORT_HELP['template']['delete']}")
 @command_doc(CLI_COMMANDS_HELP['template']['delete'])
@@ -1006,7 +1008,7 @@ def delete_template(key, key_option, stage, input, format, verbosity, global_sco
             output = format_data(result, '', 'json') ### FIXME: use a global output format setting
             if output: Pager.page(output)
 
-###--------------------------------------------------------------------------------------------
+
 
 @template.command('render', context_settings=DEFAULT_CLICK_CONTEXT, short_help=f"{CLI_COMMANDS_SHORT_HELP['template']['render']}")
 @command_doc(CLI_COMMANDS_HELP['template']['render'])
@@ -1048,9 +1050,9 @@ def render_template(stage, filter, verbosity, global_scope, project_scope, confi
             raise
 
 
-###--------------------------------------------------------------------------------------------
-###--------------------------------------------------------------------------------------------
-###--------------------------------------------------------------------------------------------
+
+
+
 
 @package.command('list', context_settings=DEFAULT_CLICK_CONTEXT, short_help="List available packages")
 @click.option('-s', '--stage', metavar='<name>[/<number>]', default='default', help=f"{CLI_PARAMETERS_HELP['common']['stage']}")
@@ -1086,7 +1088,7 @@ def list_package(stage, format, verbosity, global_scope, project_scope, config_o
         if verbosity >= log_levels['full']:
             raise
 
-###--------------------------------------------------------------------------------------------
+
 
 @package.command('download', context_settings=DEFAULT_CLICK_CONTEXT, short_help="Download a package")
 @click.option('-s', '--stage', metavar='<name>[/<number>]', default='default', help=f"{CLI_PARAMETERS_HELP['common']['stage']}")
@@ -1124,7 +1126,7 @@ def download_package(stage, package, format, verbosity, global_scope, project_sc
         if verbosity >= log_levels['full']:
             raise
 
-###--------------------------------------------------------------------------------------------
+
 
 @package.command('create', context_settings=DEFAULT_CLICK_CONTEXT, short_help="Create a package")
 @click.option('-s', '--stage', metavar='<name>[/<number>]', default='default', help=f"{CLI_PARAMETERS_HELP['common']['stage']}")
@@ -1162,7 +1164,7 @@ def create_package(stage, description, format, verbosity, global_scope, project_
         if verbosity >= log_levels['full']:
             raise
 
-###--------------------------------------------------------------------------------------------
+
 
 @package.command('delete', context_settings=DEFAULT_CLICK_CONTEXT, short_help="Delete a package")
 @click.option('-s', '--stage', metavar='<name>[/<number>]', default='default', help=f"{CLI_PARAMETERS_HELP['common']['stage']}")
@@ -1200,7 +1202,7 @@ def delete_package(stage, package, format, verbosity, global_scope, project_scop
         if verbosity >= log_levels['full']:
             raise
 
-###--------------------------------------------------------------------------------------------
+
 
 @release.command('list', context_settings=DEFAULT_CLICK_CONTEXT, short_help="List available releases")
 @click.option('-s', '--stage', metavar='<name>[/<number>]', default='default', help=f"{CLI_PARAMETERS_HELP['common']['stage']}")
@@ -1236,7 +1238,7 @@ def list_release(stage, format, verbosity, global_scope, project_scope, config_o
         if verbosity >= log_levels['full']:
             raise
 
-###--------------------------------------------------------------------------------------------
+
 
 @release.command('download', context_settings=DEFAULT_CLICK_CONTEXT, short_help="Download a release")
 @click.option('-s', '--stage', metavar='<name>[/<number>]', default='default', help=f"{CLI_PARAMETERS_HELP['common']['stage']}")
@@ -1274,7 +1276,7 @@ def download_release(stage, release, format, verbosity, global_scope, project_sc
         if verbosity >= log_levels['full']:
             raise
 
-###--------------------------------------------------------------------------------------------
+
 
 @release.command('create', context_settings=DEFAULT_CLICK_CONTEXT, short_help="Create a release")
 @click.option('-s', '--stage', metavar='<name>[/<number>]', default='default', help=f"{CLI_PARAMETERS_HELP['common']['stage']}")
@@ -1314,7 +1316,7 @@ def create_release(stage, description, format, verbosity, global_scope, project_
             raise
 
 
-###--------------------------------------------------------------------------------------------
+
 
 @release.command('delete', context_settings=DEFAULT_CLICK_CONTEXT, short_help="Delete a release")
 @click.option('-s', '--stage', metavar='<name>[/<number>]', default='default', help=f"{CLI_PARAMETERS_HELP['common']['stage']}")
@@ -1352,7 +1354,7 @@ def delete_release(stage, release, format, verbosity, global_scope, project_scop
         if verbosity >= log_levels['full']:
             raise
 
-###--------------------------------------------------------------------------------------------
+
 
 @release.command('deploy', context_settings=DEFAULT_CLICK_CONTEXT, short_help="Deploy a release")
 @click.option('-s', '--stage', metavar='<name>[/<number>]', default='default', help=f"{CLI_PARAMETERS_HELP['common']['stage']}")
@@ -1390,7 +1392,7 @@ def deploy_release(stage, release, format, verbosity, global_scope, project_scop
         if verbosity >= log_levels['full']:
             raise
 
-###--------------------------------------------------------------------------------------------
+
 
 @config.command('get', context_settings=DEFAULT_CLICK_CONTEXT, short_help=f"{CLI_COMMANDS_SHORT_HELP['config']['get']}")
 @command_doc(CLI_COMMANDS_HELP['config']['get'])
@@ -1432,7 +1434,7 @@ def get_config(key, key_option, local, global_, verbosity, global_scope, project
         if verbosity >= log_levels['full']:
             raise
 
-###--------------------------------------------------------------------------------------------
+
 
 @config.command('set', context_settings=DEFAULT_CLICK_CONTEXT, short_help=f"{CLI_COMMANDS_SHORT_HELP['config']['set']}")
 @command_doc(CLI_COMMANDS_HELP['config']['set'])
@@ -1481,7 +1483,7 @@ def set_config(key, key_option, value, value_option, global_, input, verbosity,
         if verbosity >= log_levels['full']:
             raise
 
-###--------------------------------------------------------------------------------------------
+
 
 @config.command('delete', context_settings=DEFAULT_CLICK_CONTEXT, short_help=f"{CLI_COMMANDS_SHORT_HELP['config']['delete']}")
 @command_doc(CLI_COMMANDS_HELP['config']['set'])
@@ -1516,7 +1518,7 @@ def delete_config(key, key_option, global_, verbosity, global_scope, project_sco
         if verbosity >= log_levels['full']:
             raise
 
-###--------------------------------------------------------------------------------------------
+
 
 # @config.command('setup', context_settings=DEFAULT_CLICK_CONTEXT, short_help=f"{CLI_COMMANDS_SHORT_HELP['config']['setup']}")
 # @click.option('-w','--working-dir', metavar='<path>', type=click.Path(exists=True, file_okay=False), required=False, help=f"{CLI_PARAMETERS_HELP['common']['working_dir']}")
@@ -1546,7 +1548,7 @@ def delete_config(key, key_option, global_, verbosity, global_scope, project_sco
 #         if verbosity >= log_levels['full']:
 #             raise
 
-###--------------------------------------------------------------------------------------------
+
 
 @config.command('init', context_settings=DEFAULT_CLICK_CONTEXT, short_help=f"{CLI_COMMANDS_SHORT_HELP['config']['init']}")
 @command_doc(CLI_COMMANDS_HELP['config']['init'])
@@ -1589,7 +1591,7 @@ def init_config(setup, local, input, verbosity, global_scope, project_scope, con
         if verbosity >= log_levels['full']:
             raise
 
-###--------------------------------------------------------------------------------------------
+
 
 modify_click_usage_error()
 
