@@ -8,9 +8,7 @@ from .exceptions import DSOException
 from .cli_constants import *
 from functools import reduce
 
-DEFAULT_CLICK_CONTEXT = dict(help_option_names=['-h', '--help'])
 
-###--------------------------------------------------------------------------------------------
 
 def format_data(data, query, format):
 
@@ -157,7 +155,7 @@ def format_data(data, query, format):
     else:
         raise DSOException(f"Output format '{format}' is not supported.")
 
-###--------------------------------------------------------------------------------------------
+
 
 def read_data(input, parent_key, keys, format):
     result = []
@@ -253,13 +251,13 @@ def read_data(input, parent_key, keys, format):
     
     return result
 
-###--------------------------------------------------------------------------------------------
+
 
 # def validate_multiple_argument(ctx, param, value):
 #     if len(value) > 1:
 #         raise DSOException(f"Multiple '{param.name}' {type(param)} is not allowd.")
 
-###--------------------------------------------------------------------------------------------
+
 
 def validate_only_one_provided(values, names, causes=[]):
 
@@ -274,7 +272,7 @@ def validate_only_one_provided(values, names, causes=[]):
     # return list(filter(lambda i: bool(values[i]), range(len(values))))
     return reduce(lambda x, y: x or y, values)
 
-###--------------------------------------------------------------------------------------------
+
 
 ### opposite validate_not_all_provided
 def validate_all_provided(values, names, causes=[]):
@@ -289,7 +287,7 @@ def validate_all_provided(values, names, causes=[]):
     
     # return list(filter(lambda i: not bool(values[i]), range(len(values))))
 
-###--------------------------------------------------------------------------------------------
+
 
 ### opposite validate_all_provided
 def validate_not_all_provided(values, names, causes=[]):
@@ -305,7 +303,7 @@ def validate_not_all_provided(values, names, causes=[]):
     # return list(filter(lambda i: bool(values[i]), range(len(values))))
     return reduce(lambda x, y: x or y, values)
 
-###--------------------------------------------------------------------------------------------
+
 
 ### opposite validate_at_least_one_provided
 def validate_none_provided(values, names, causes=[]):
@@ -321,7 +319,7 @@ def validate_none_provided(values, names, causes=[]):
     
     # return list(filter(lambda i: bool(values[i]), range(len(values))))
 
-###--------------------------------------------------------------------------------------------
+
 
 ### opposite validate_none_provided
 def validate_at_least_one_provided(values, names, causes=[]):
@@ -337,7 +335,7 @@ def validate_at_least_one_provided(values, names, causes=[]):
 
     return reduce(lambda x, y: x or y, values)
 
-###--------------------------------------------------------------------------------------------
+
 
 def validate_query_argument(query, query_all, default_query):
     
