@@ -6,6 +6,9 @@ from .stages import Stages
 from .constants import *
 from .exceptions import *
 
+
+REGEX_PATTERN = r"^[a-zA-Z][.a-zA-Z0-9_-]*[a-zA-ZA-Z0-9]$"
+
 class SecretProvider(StoreProvider):
     def list(self, project, application, stage, uninherited=False, decrypt=False, filter=None):
         raise NotImplementedError()
@@ -21,11 +24,13 @@ class SecretProvider(StoreProvider):
 class SecretManager():
 
     def validate_key(self, key):
-        Logger.info("Start validating secret key...")
-        Logger.debug(f"Validating: key={key}")
-        pattern = REGEX_PATTERNS['secret_key']
-        if not re.match(pattern, key):
-            raise DSOException(MESSAGES['InvalidKeyPattern'].format(key, pattern))
+        Logger.info(f"Validating secret key '{key}'...")
+        if not key:
+            raise DSOException(MESSAGES['KeyNull'])
+        if key == 'dso' or key.startswith('dso.'):
+            raise DSOException(MESSAGES['DSOReserverdKey'].format(key))
+        if not re.match(REGEX_PATTERN, key):
+            raise DSOException(MESSAGES['InvalidKeyPattern'].format(key, REGEX_PATTERN))
         if '..' in key:
             raise DSOException(MESSAGES['InvalidKeyStr'].format(key, '..'))
 
